@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2000-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -367,6 +367,7 @@ static int t_preprocess_only(void)
       if (rc != 0) {
 	    if (WIFEXITED(rc)) {
 		  fprintf(stderr, "errors preprocessing Verilog program.\n");
+		  free(cmd);
 		  return WEXITSTATUS(rc);
 	    }
 
@@ -568,6 +569,11 @@ void process_define(const char*name)
       fprintf(defines_file,"D:%s\n", name);
 }
 
+void process_timescale(const char*ts_string)
+{
+      fprintf(iconfig_file, "timescale:%s\n", ts_string);
+}
+
 /*
  * This function is called while processing a file name in a command
  * file, or a file name on the command line. Look to see if there is a
@@ -639,10 +645,10 @@ int process_generation(const char*name)
 
       else if (strcmp(name,"no-std-include") == 0)
 	     gen_std_include = 0;
-      
+
       else if (strcmp(name,"relative-include") == 0)
 	    gen_relative_include = 1;
-      
+
       else if (strcmp(name,"no-relative-include") == 0)
 	    gen_relative_include = 0;
 
@@ -663,7 +669,7 @@ int process_generation(const char*name)
 
       else if (strcmp(name,"no-verilog-ams") == 0)
 	    gen_verilog_ams = "no-verilog-ams";
-      
+
       else if (strcmp(name,"system-verilog") == 0)
 	    gen_system_verilog = "system-verilog";
 
@@ -726,10 +732,10 @@ int main(int argc, char **argv)
 	   turning the last two \ characters to null. Then we append
 	   the lib\ivl$(suffix) to finish. */
       { char *s;
-	char basepath[4096], tmp[4096];
-	GetModuleFileName(NULL, tmp, sizeof tmp);
+	char basepath[4096], tmppath[4096];
+	GetModuleFileName(NULL, tmppath, sizeof tmppath);
 	  /* Convert to a short name to remove any embedded spaces. */
-	GetShortPathName(tmp, basepath, sizeof basepath);
+	GetShortPathName(tmppath, basepath, sizeof basepath);
 	strncpy(ivl_root, basepath, MAXSIZE);
 	s = strrchr(ivl_root, sep);
 	if (s) *s = 0;
@@ -930,10 +936,19 @@ int main(int argc, char **argv)
 
       if (version_flag || verbose_flag) {
 	    printf("Icarus Verilog version " VERSION " (" VERSION_TAG ")\n\n");
-	    printf("Copyright 1998-2009 Stephen Williams\n\n");
+	    printf("Copyright 1998-2010 Stephen Williams\n\n");
 	    puts(NOTICE);
       }
 
+      if (synth_flag) {
+	    fprintf(stderr, "Warning: Synthesis is not currently being "
+	                    "maintained and may not\n");
+	    fprintf(stderr, "         function correctly. V0.8 was the "
+	                    "last release branch to\n");
+	    fprintf(stderr, "         have active synthesis development "
+	                    "and support!\n");
+      }
+
 	/* Make a common conf file path to reflect the target. */
       snprintf(iconfig_common_path, sizeof iconfig_common_path, "%s%c%s%s.conf",
 	      base, sep, targ, synth_flag? "-s" : "");
@@ -1026,7 +1041,7 @@ int main(int argc, char **argv)
 
 	/* If we are planning on opening a dependencies file, then
 	   open and truncate it here. The other phases of compilation
-	   will append to the file, so this is necessray to make sure
+	   will append to the file, so this is necessary to make sure
 	   it starts out empty. */
       if (depfile) {
 	    FILE*fd = fopen(depfile, "w");
