@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2000-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -27,10 +27,7 @@
 # include  "ivl_target.h"
 # include  "compiler.h"
 # include  "t-dll.h"
-#ifdef HAVE_MALLOC_H
-# include  <malloc.h>
-#endif
-# include  <stdlib.h>
+# include  <cstdlib>
 
 bool dll_target::process(const NetProcTop*net)
 {
