@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2000-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -20,7 +20,6 @@
 # include "sys_priv.h"
 # include "sys_random.h"
 
-# include  <vpi_user.h>
 # include  <assert.h>
 # include  <stdlib.h>
 # include  <math.h>
@@ -877,7 +876,7 @@ static PLI_INT32 sys_dist_erlang_calltf(PLI_BYTE8 *name)
       i_mean = val.value.integer;
 
       /* Calculate and return the result. */
-      val.value.integer = rtl_dist_normal(&i_seed, i_k, i_mean);
+      val.value.integer = rtl_dist_erlang(&i_seed, i_k, i_mean);
       vpi_put_value(callh, &val, 0, vpiNoDelay);
 
       /* Return the seed. */
