@@ -21,11 +21,10 @@
 # include  "vthread.h"
 # include  "slab.h"
 # include  <new>
-# include  <signal.h>
-# include  <stdlib.h>
-# include  <assert.h>
-
-# include  <stdio.h>
+# include  <typeinfo>
+# include  <csignal>
+# include  <cstdlib>
+# include  <cassert>
 
 unsigned long count_assign_events = 0;
 unsigned long count_gen_events = 0;
@@ -370,7 +369,7 @@ bool schedule_stopped(void)
  * These are the signal handling infrastructure. The SIGINT signal
  * leads to an implicit $stop.
  */
-static void signals_handler(int)
+extern "C" void signals_handler(int)
 {
       schedule_stopped_flag = true;
 }
